<?php

/**
 * @file
 *
 * Message send page.
 */

/**
 * Send messages.
 *
 * @param $form
 * @param $form_state
 *
 * @return array
 */
function smsc_config_form($form, &$form_state) {

  $drupalSmsc = smsc_get_smsc();
  $config     = $drupalSmsc->getConfig();

  $form_state['smsc.config'] = $config->getConfig();

  /* <-- Authorization --> */

  $form['authorization'] = [
    '#type'        => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed'   => $config->hasSettings(),
    '#description' => t('Authorization data on SMSC service.'),
    '#title'       => t('Authorization'),
  ];

  $form['authorization']['login'] = [
    '#type'          => 'textfield',
    '#title'         => t('SMSC Login'),
    '#description'   => t('Your login on SMSC service.'),
    '#default_value' => $config->get('login'),
  ];

  $form['authorization']['psw'] = [
    '#type'        => 'password',
    '#title'       => t('SMSC Password'),
    '#description' => t('Your password on SMSC service.'),
    '#attributes'  => ['autocomplete' => 'off'],
  ];

  $form['authorization']['host'] = [
    '#type'          => 'select',
    '#options'       => $drupalSmsc->getHosts(),
    '#title'         => t('API Host'),
    '#description'   => t('SMSC API host.'),
    '#default_value' => $config->get('host'),
  ];

  /* <-- /Authorization --> */

  /* <-- Settings --> */

  $form['settings'] = [
    '#type'        => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed'   => !$config->hasSettings(),
    '#title'       => t('Default settings'),
  ];

  $senders = $drupalSmsc->getSenders();

  $default_sender = '';

  if ($config->hasSettings() && $senders && count($senders)) {
    $default_sender = $config->get('sender');
  }

  $default_sender = in_array($default_sender, $senders) ? $default_sender : '';

  $form['settings']['sender'] = [
    '#type'          => 'select',
    '#options'       => $senders,
    '#title'         => t('Sender ID'),
    '#description'   => t('Default sender ID.'),
    '#default_value' => $default_sender,
  ];

  $form['settings']['translit'] = [
    '#type'          => 'checkbox',
    '#title'         => t('Translit'),
    '#description'   => t('Transliterate messages by default.'),
    '#default_value' => $config->get('translit'),
  ];

  $form['actions'] = [
    '#type' => 'actions',
  ];

  $form['actions']['submit'] = [
    '#type'  => 'submit',
    '#value' => t('Save'),
  ];

  return $form;
}

/**
 * Submit form.
 *
 * @param $form
 * @param $form_state
 */
function smsc_config_form_submit($form, &$form_state) {
  $drupalSmsc = smsc_get_smsc();
  $config     = $drupalSmsc->getConfig();

  $unsavedData = $form_state['smsc.config'];

  form_state_values_clean($form_state);

  $savedData = $form_state['values'];

  if (smsc_compare_config_data($unsavedData, $savedData)) {
    smsc_invalidate_cached_data('smsc:senders');
  }

  $config->set('login', $form_state['values']['login']);

  if (!empty($form_state['values']['psw'])) {
    $config->set('psw', md5($form_state['values']['psw']));
  }

  if (!empty($form_state['values']['host'])) {
    $config->set('host', $form_state['values']['host']);
  }

  if (isset($form_state['values']['sender'])) {
    $config->set('sender', $form_state['values']['sender']);
  }

  if (isset($form_state['values']['translit'])) {
    $config->set('translit', $form_state['values']['translit']);
  }

  $config->save();
}

/**
 * Compare data.
 *
 * @param $unsaved
 * @param $new
 *
 * @return bool
 */
function smsc_compare_config_data($unsaved, $new) {
  return (
    $unsaved['login'] != $new['login'] ||
    (!empty($new['psw']) && $unsaved['psw'] != $new['psw'])
  );
}

/**
 * Invalidate SMSC caches.
 *
 * @param $cid
 */
function smsc_invalidate_cached_data($cid) {
  cache_clear_all($cid, $bin = 'cache');
}
