<?php

/**
 * Implement hook_rules_action_info()
 */
function smsc_rules_action_info() {
  $drupalSmsc = smsc_get_smsc();
  $config     = $drupalSmsc->getConfig();

  $actions = [
    'smsc_rules_send' => [
      'label'     => t('Send SMSC message'),
      'group'     => t('SMSC'),
      'module'    => 'smsc',
      'parameter' => [
        'phone'    => [
          'type'        => 'text',
          'label'       => t('Phones'),
          'description' => t('Phones list (coma separated) or single phone.'),
        ],
        'message'  => [
          'type'        => 'text',
          'label'       => t('Message'),
          'description' => t('Message text.'),
        ],
        'translit' => [
          'type'          => 'boolean',
          'label'         => t('Transliterate'),
          'description'   => t('Transliterate message.'),
          'optional'      => TRUE,
          'default value' => empty($config->get('translit')) ? FALSE : $config->get('translit'),
        ],
        'sender'   => [
          'type'          => 'text',
          'label'         => t('Sender ID'),
          'description'   => t('Sender ID.'),
          'options list'  => 'smsc_rules_get_senders',
          'default value' => smsc_rules_get_senders_key($config->get('sender')),
        ],
      ],
    ],

  ];

  return $actions;
}

/**
 * The action function for smsc_send_sms
 *
 * @param string $phones
 * @param string $message
 * @param bool   $translit
 * @param string $sender
 */
function smsc_rules_send($phones, $message, $translit = NULL, $sender = NULL) {
  $drupalSmsc = smsc_get_smsc();

  $senders = smsc_rules_get_senders();

  $options = [
    'translit' => $translit,
    'sender'   => isset($senders[$sender]) ? $senders[$sender] : '',
  ];

  $drupalSmsc::sendSms($phones, $message, $options);
}

/**
 * Get available senders.
 *
 * @return array
 */
function smsc_rules_get_senders() {
  $drupalSmsc = &drupal_static(__FUNCTION__);

  if (!isset($drupalSmsc)) {
    $drupalSmsc = smsc_get_smsc();
  }

  return array_values($drupalSmsc->getSenders());
}

/**
 * Get sender key.
 *
 * @param string $sender
 *
 * @return int
 */
function smsc_rules_get_senders_key($sender) {
  return (int) array_search($sender, smsc_rules_get_senders());
}
